Small test repository.

This repository is populated using tests/populate_test_content/populate_test_file.py

repopulating the test repository requires https://github.com/xDBio-Inc/cwl-source to be present in a sibling directory of this project.